#include <conio.h>
#include <stdio.h>
#include <math.h>

#include "munpos.h"

static void disp(int id, const char *name, double *cusps, double *pos);

typedef struct {
  const char* name;
  unsigned hsys;
  double shift;
} HSYS;

int main()
{
  double eps, st, geolon, geolat;
  double SU_lon = 232.42;
  double cusps[12], pos[12];
  int i, j;
  HSYS hsys[18];
  MUNPOS mp;

  hsys[ 0].name = "MC-EQUAL";                           hsys[ 0].hsys = mpMCEQ;             hsys[ 0].shift =   0.0;
  hsys[ 1].name = "MERIDIAN alias AXIAL ROTATION";      hsys[ 1].hsys = mpMERI;             hsys[ 1].shift =   0.0;

  hsys[ 2].name = "AC-EQUAL";                           hsys[ 2].hsys = mpACEQ;             hsys[ 2].shift =   0.0;
  hsys[ 3].name = "POLI-EQUATORIAL (Carter)";           hsys[ 3].hsys = mpPOLI;             hsys[ 3].shift =   0.0;

  hsys[ 4].name = "PORPHYRY";                           hsys[ 4].hsys = mpPORP;             hsys[ 4].shift =   0.0;
  hsys[ 5].name = "ALCABITIUS";                         hsys[ 5].hsys = mpALCA;             hsys[ 5].shift =   0.0;

  hsys[ 6].name = "CAMPANUS";                           hsys[ 6].hsys = mpCAMP;             hsys[ 6].shift =   0.0;
  hsys[ 7].name = "REGIOMONTANUS";                      hsys[ 7].hsys = mpREGI;             hsys[ 7].shift =   0.0;

  hsys[ 8].name = "PLACIDUS";                           hsys[ 8].hsys = mpPLAC;             hsys[ 8].shift =   0.0;
  hsys[ 9].name = "TOPOCENTRIC";                        hsys[ 9].hsys = mpTOPO;             hsys[ 9].shift =   0.0;

  hsys[10].name = "HORIZONTAL (Campanus azimuthal)";    hsys[10].hsys = mpCAMP | mpPOLAR;   hsys[10].shift =   0.0;
  hsys[11].name = "PLACIDUS azimuthal";                 hsys[11].hsys = mpPLAC | mpPOLAR;   hsys[11].shift =   0.0;

  hsys[12].name = "ABENRAGEL (APC)";                    hsys[12].hsys = mpHALY;             hsys[12].shift =   0.0;
  hsys[13].name = "SOLARIS (M. J. Makransky)";          hsys[13].hsys = mpHALY;             hsys[13].shift =   0.0;

  hsys[14].name = "KOCH";                               hsys[14].hsys = mpKOCH;             hsys[14].shift =   0.0;
  hsys[15].name = "MORINUS";                            hsys[15].hsys = mpMORI;             hsys[15].shift =   0.0;

  hsys[16].name = "VEHLOW (AC-Equal -15)";              hsys[16].hsys = mpACEQ;             hsys[16].shift = -15.0;
  hsys[17].name = "CAMPANUS clockwise";                 hsys[17].hsys = mpCAMP | mpREVERSE; hsys[17].shift =   0.0;

  eps = 23.4459;
  st = 12.37;
  geolon = 0.0;
  geolat = 51.5;

  mpSetEvent(&mp, eps, st, geolon, geolat);

  for(i = 0; i < 18; i += 2) 
  {
    mpSetHsysShift(&mp, hsys[i].hsys, hsys[i].shift);
    mpCalcCusps(&mp, 12, cusps);
    for(j = 0; j < 12; j++)
      pos[j] = mpCalcPosition(&mp, cusps[j], 0.0);
    disp(i + 1, hsys[i].name, cusps, pos);  

    mpSetHsysShift(&mp, hsys[i + 1].hsys , hsys[i + 1].shift);
    /* solar house system */
    if(hsys[i + 1].hsys == mpHALY)
      mpSetDecl(&mp, mpCalcDE(&mp, SU_lon, 0.0));
    /* ------------------ */
    mpCalcCusps(&mp, 12, cusps);
    for(j = 0; j < 12; j++)
      pos[j] = mpCalcPosition(&mp, cusps[j], 0.0);
    disp(i + 2, hsys[i + 1].name, cusps, pos);

    if(i < 16)
      printf("\n Press any key to continue...\n ");

    else
      printf("\n Press any key to exit...\n ");
    if(getch() == 0x1b) break;  /* escape */
  }
  return 0;
}

static void disp(int id, const char *name, double *cusps, double *pos)
{
  int i, j;
  printf("\n %02d %s\n", id, name);
  puts(" ===========================================================================");
  j = 6;
  for(i = 0; i < j; i++)
    printf("%11.6f  ", cusps[i]);
  puts("");
  for(i = j; i < 2 * j; i++)
    printf("%11.6f  ", cusps[i]);

  puts("\n");
  puts(" re-calculated mundane position");
  puts(" ---------------------------------------------------------------------------");
  for(i = 0; i < j; i++)
    printf("%11.6f  ", pos[i]);
  puts("");
  for(i = j; i < 2 * j; i++)
    printf("%11.6f  ", pos[i]);
  printf("\n\n");
}
