/**
Dieser Test vergleicht die mit den Funktionen mpCalcArc... 
berechneten Direktionsboegen mit den Beispielen wie sie im 
Buch "Primary Directions - A Primer of Calculation" von 
Bob Makransky abgedruckt sind.
Siehe: www.dearbrutus.com
*/

#include <conio.h>
#include <stdio.h>
#include "munpos.h"

#define mpHORIZON (mpCAMP | mpPOLAR)

#define STD (mpLAT_S | mpLAT_P)   /* MUNDANE CONJUNCTIONS         */
#define ZOD  mpLAT_S              /* ZODIACAL DIRECTIONS          */
#define MUN (STD | mpMUNDO)       /* MUNDANE ASPECTUAL DIRECTIONS */
#define PAR (MUN | mpMIRROR)      /* MUNDANE PARALLELS            */

double const eps = 23.4459;
double const st = 12.37;
double const geolon = 0.0;
double const geolat = 51.5;

double const SU_lon = 232.42, SU_lat =          0.;
double const MO_lon =  30.44, MO_lat =     -25./60.;
double const ME_lon = 216.96, ME_lat =   1.+47./60.;
double const VE_lon = 196.38, VE_lat =   1.+50./60.;
double const JU_lon = 269.89, JU_lat =       4./60.;
double const SA_lon = 155.27, SA_lat =   1.+26./60.;
double const UR_lon =  89.93, UR_lat =      12./60.;
double const PL_lon = 136.56, PL_lat =    7+33./60.;
double const CO_lon = 197.96, CO_lat = -21.-13./60.;

int main()
{
  double mpos, arc, vect[6];
  MUNPOS mp; 
  mpSetEvent(&mp, eps, st, geolon, geolat);
       
  puts("\n HOUSE SYSTEM    RESULT   EXAMPLE  PAGE     DIRECTION");
  puts(" ---------------------------------------------------------------");

  mpSetHsys(&mp, mpCAMP);
  /* ------------------------------------- */
  arc = mpCalcArc(&mp, MO_lon, MO_lat, 270.0, STD, 0.0);
  printf(" Campanus       %7.2f     16.11    22     MO con MC\n", arc);

  arc = mpCalcArc(&mp, SU_lon, SU_lat, 90.0, STD, 0.0);
  printf(" Campanus       %7.2f     37.64    22     SO con IC\n", arc);

  arc = mpCalcArc(&mp, SA_lon, SA_lat, 90.0, STD, 0.0);
  printf(" Campanus       %7.2f    -34.74    22     SA con IC\n", arc);

  arc = mpCalcArc(&mp, CO_lon, CO_lat, 90.0, STD, 0.0);
  printf(" Campanus       %7.2f     -4.68    22     CO con IC\n", arc);

  arc = mpCalcArc(&mp, PL_lon, PL_lat, 0.0, STD, 0.0);
  printf(" Campanus       %7.2f      6.75    23     PL con ASC\n", arc);

  arc = mpCalcArc(&mp, UR_lon, UR_lat, 0.0, STD, 0.0);
  printf(" Campanus       %7.2f    -45.84    23     UR con ASC\n", arc);

  arc = mpCalcArc(&mp, JU_lon, JU_lat, 180.0, STD, 0.0);
  printf(" Campanus       %7.2f    -45.43    23     JU con DESC\n", arc);

  arc = mpCalcArc(&mp, MO_lon, 0.0, 270.0, STD, 0.0);
  printf(" Campanus       %7.2f     15.95    25     MO con MC zod\n", arc);

  arc = mpCalcArc(&mp, SU_lon, 0.0, 90.0, STD, 0.0);
  printf(" Campanus       %7.2f     37.64    25     SU con IC zod\n", arc);

  arc = mpCalcArc(&mp, CO_lon, 0.0, 90.0, STD, 0.0);
  printf(" Campanus       %7.2f      4.18    25     CO con IC zod\n", arc);

  arc = mpCalcArc(&mp, PL_lon, 0.0, 0.0, STD, 0.0);
  printf(" Campanus       %7.2f     15.70    26     PL con AC zod\n", arc);

  arc = mpCalcArc(&mp, JU_lon, 0.0, 180.0, STD, 0.0);
  printf(" Campanus       %7.2f    -45.54    26     JU con DC zod\n", arc);

  arc = mpCalcArc2(&mp, SU_lon, SU_lat, ME_lon, ME_lat, STD, 0.0);
  printf(" Campanus       %7.2f     12.17    40     SU con ME\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat, VE_lon, VE_lat, STD, 0.0);
  printf(" Campanus       %7.2f    -37.09    40     SA con VE\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Campanus       %7.2f     -5.50    41     MO tri SA zod\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat,  ME_lon, ME_lat, PAR, 90.0);
  printf(" Campanus       %7.2f    -21.01    43     SA || ME\n", arc);

  mpos = mpCalcPosition(&mp, ME_lon, ME_lat);
  mpCalcArcRapt(&mp, SU_lon, SU_lat, JU_lon, JU_lat, mpos, vect);
  printf(" Campanus       %7.2f     28.72    47     SU/JU = ME Rapt||\n", vect[4]);

  mpos = mpCalcPosition(&mp, SU_lon, SU_lat);
  mpCalcArcRapt(&mp, MO_lon, MO_lat, UR_lon, UR_lat, mpos, vect);
  printf(" Campanus       %7.2f      3.37    47     MO/UR = SU Rapt||\n", vect[4]);

  mpSetHsys(&mp, mpREGI);
  /* ------------------------------------------------------- */
  mpos = mpCalcPosition(&mp, ME_lon, ME_lat);
  mpCalcArcRapt(&mp, SU_lon, SU_lat, JU_lon, JU_lat, mpos, vect);
  printf(" Regiomontanus  %7.2f     30.37    47     SU/JU = ME Rapt||\n", vect[4]);


  printf("\n Press any key to continue...\n ");
  getch();
  puts("\n HOUSE SYSTEM    RESULT   EXAMPLE  PAGE     DIRECTION");
  puts(" ---------------------------------------------------------------");

  mpos = mpCalcPosition(&mp, SU_lon, SU_lat);
  mpCalcArcRapt(&mp, MO_lon, MO_lat, UR_lon, UR_lat, mpos, vect);
  printf(" Regiomontanus  %7.2f      7.38    47     MO/UR = SU Rapt||\n", vect[4]);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Regiomontanus  %7.2f     -3.19    44     MO tri SA mund asp\n", arc);

  mpSetHsys(&mp, mpHORIZON);
  /* ------------------------------------------------------- */
  arc = mpCalcArc(&mp, JU_lon, JU_lat, 180.0, STD, 0.0);
  printf(" Horizon        %7.2f      7.62    24     JU con VTX mund\n", arc);

  arc = mpCalcArc(&mp, PL_lon, 0.0, 0.0, STD, 0.0);
  printf(" Horizon        %7.2f     49.73    24     PL con AVTX zod\n", arc);

  arc = mpCalcArc(&mp, JU_lon, 0.0, 180.0, STD, 0.0);
  printf(" Horizon        %7.2f      7.68    24     JU con VTX zod\n", arc);

  arc = mpCalcArc2(&mp, SU_lon, SU_lat, ME_lon, ME_lat, STD, 0.0);
  printf(" Horizon        %7.2f     17.25    55     SU con ME\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat, VE_lon, VE_lat, STD, 0.0);
  printf(" Horizon        %7.2f    -38.96    55     SA con VE\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Horizon        %7.2f     -4.96    55     MO tri SA zod\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat, ME_lon, ME_lat, PAR, 90.0);
  printf(" Horizon        %7.2f     -3.32    57     SA || ME\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Horizon        %7.2f      0.41    59     MO tri SA mund asp\n", arc);

  mpSetHsys(&mp, mpMERI);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, SU_lon, SU_lat, ME_lon, ME_lat, STD, 0.0);
  printf(" Meridian       %7.2f     14.79    60     SU con ME\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Meridian       %7.2f     -9.16    61     MO tri SA mund asp\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Meridian       %7.2f     -5.13    61     MO tri SA zod\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat, ME_lon, ME_lat, PAR, 90.0);
  printf(" Meridian       %7.2f    -11.89    61     SA || ME\n", arc);

  mpSetHsys(&mp, mpMORI);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, SU_lon, SU_lat, ME_lon, ME_lat, STD, 0.0);
  printf(" Morinus        %7.2f     17.05    63     SU con ME\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Morinus        %7.2f     -5.29    63     MO tri SA zod\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Morinus        %7.2f     -0.74    64     MO tri SA mund asp\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat, ME_lon, ME_lat, PAR, mpCalcPosition(&mp, 0., 0.));
  printf(" Morinus        %7.2f     13.28    65     SA # ME\n", arc);

  mpSetHsys(&mp, mpACEQ);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" AC-equal       %7.2f     -5.25    65     MO tri SA mund asp\n", arc);


  printf("\n Press any key to continue...\n ");
  getch();
  puts("\n HOUSE SYSTEM    RESULT   EXAMPLE  PAGE     DIRECTION");
  puts(" ---------------------------------------------------------------");

  mpSetHsys(&mp, mpPORP);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Porphyry       %7.2f      5.72    67     MO tri SA mund asp\n", arc);

  mpSetHsys(&mp, mpALCA);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Alcabitius     %7.2f      1.30    69     MO tri SA mund asp\n", arc);

  mpSetHsys(&mp, mpKOCH);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, SU_lon, SU_lat, ME_lon, ME_lat, STD, 0.0);
  printf(" Koch           %7.2f      5.82    70     SU con ME\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Koch           %7.2f     -5.68    70     MO tri SA zod\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Koch           %7.2f     -0.65    72     MO tri SA mund asp\n", arc);

  mpSetHsys(&mp, mpPLAC);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, SU_lon, SU_lat, ME_lon, ME_lat, STD, 0.0);
  printf(" Placidus       %7.2f     12.85    78     SU con ME\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Placidus       %7.2f     -5.38    78     MO tri SA zod\n", arc);

  arc = mpCalcArc2(&mp, SA_lon, SA_lat, ME_lon, ME_lat, PAR, 90.0);
  printf(" Placidus       %7.2f    -18.32    79     SA || ME\n", arc);

  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Placidus       %7.2f     -5.77    79     MO tri SA mund asp\n", arc);

  mpSetHsys(&mp, mpPOPA);
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, ZOD, 120.0);
  printf(" Topocentric    %7.2f     -5.37    85     MO tri SA zod\n", arc);

  mpSetHsys(&mp, mpHALY); 
  mpSetDecl(&mp, mpCalcDE(&mp, SU_lon, SU_lat));
  /* ------------------------------------------------------- */
  arc = mpCalcArc2(&mp, MO_lon, MO_lat, SA_lon, SA_lat, MUN, -120.0);
  printf(" Solar System   %7.2f     -1.97   149     MO tri SA mund asp\n", arc);


  printf("\n\n\n\n\n\n\n\n\n Press any key to exit...\n ");
  getch();

  return(0);
}
